@@ -37,7 +37,7 @@ def _convert_legacy_to_enhanced(
     ----------
     sf_datasets: Sequence[pydicom.dataset.Dataset]
         DICOM data sets of single-frame legacy image instances
-    mf_dataset: pydicom.dataset.Dataset, optional
+    mf_dataset: Union[pydicom.dataset.Dataset, None], optional
         DICOM data set of multi-frame enhanced image instance
 
     Returns
@@ -108,7 +108,8 @@ def _convert_legacy_to_enhanced(
             # Only root-level attributes
             if len(attr_item['path']) > 0:
                 continue
-            tag = tag_for_keyword(attr_item['keyword'])
+            keyword: str = attr_item['keyword']
+            tag = tag_for_keyword(keyword)
             if tag in ignored_attributes:
                 continue
             mf_attributes.append(tag)
