@@ -9,7 +9,8 @@ from pydicom._storage_sopclass_uids import SecondaryCaptureImageStorage
 from pydicom.dataset import Dataset
 from pydicom.encaps import encapsulate
 from pydicom.sr.codedict import codes
-from pydicom.valuerep import DA, TM
+from pydicom.sr.coding import Code
+from pydicom.valuerep import DA, PersonName, TM
 from pydicom.uid import (
     ImplicitVRLittleEndian,
     ExplicitVRLittleEndian,
@@ -28,10 +29,12 @@ from highdicom.enum import (
     LateralityValues,
     PatientOrientationValuesBiped,
     PatientOrientationValuesQuadruped,
+    PatientSexValues,
 )
 from highdicom.frame import encode_frame
 from highdicom.sc.enum import ConversionTypeValues
 from highdicom.sr.coding import CodedConcept
+from highdicom.valuerep import check_person_name
 
 
 logger = logging.getLogger(__name__)
@@ -59,14 +62,14 @@ class SCImage(SOPClass):
             instance_number: int,
             manufacturer: str,
             patient_id: Optional[str] = None,
-            patient_name: Optional[str] = None,
+            patient_name: Optional[Union[str, PersonName]] = None,
             patient_birth_date: Optional[str] = None,
-            patient_sex: Optional[str] = None,
+            patient_sex: Union[str, PatientSexValues, None] = None,
             accession_number: Optional[str] = None,
             study_id: str = None,
             study_date: Optional[Union[str, datetime.date]] = None,
             study_time: Optional[Union[str, datetime.time]] = None,
-            referring_physician_name: Optional[str] = None,
+            referring_physician_name: Optional[Union[str, PersonName]] = None,
             pixel_spacing: Optional[Tuple[int, int]] = None,
             laterality: Optional[Union[str, LateralityValues]] = None,
             patient_orientation: Optional[
@@ -101,13 +104,13 @@ class SCImage(SOPClass):
             Array of unsigned integer pixel values representing a single-frame
             image; either a 2D grayscale image or a 3D color image
             (RGB color space)
-        photometric_interpretation: Union[str, highdicom.enum.PhotometricInterpretationValues]
+        photometric_interpretation: Union[str, highdicom.PhotometricInterpretationValues]
             Interpretation of pixel data; either ``"MONOCHROME1"`` or
             ``"MONOCHROME2"`` for 2D grayscale images or ``"RGB"`` or
             ``"YBR_FULL"`` for 3D color images
         bits_allocated: int
             Number of bits that should be allocated per pixel value
-        coordinate_system: Union[str, highdicom.enum.CoordinateSystemNames]
+        coordinate_system: Union[str, highdicom.CoordinateSystemNames]
             Subject (``"PATIENT"`` or ``"SLIDE"``) that was the target of
             imaging
         study_instance_uid: str
@@ -124,43 +127,43 @@ class SCImage(SOPClass):
             Name of the manufacturer of the device that creates the SC image
             instance (in a research setting this is typically the same
             as `institution_name`)
-        patient_id: str, optional
+        patient_id: Union[str, None], optional
            ID of the patient (medical record number)
-        patient_name: str, optional
+        patient_name: Union[str, PersonName, None], optional
            Name of the patient
-        patient_birth_date: str, optional
+        patient_birth_date: Union[str, None], optional
            Patient's birth date
-        patient_sex: str, optional
+        patient_sex: Union[str, highdicom.PatientSexValues, None], optional
            Patient's sex
-        study_id: str, optional
+        study_id: Union[str, None], optional
            ID of the study
-        accession_number: str, optional
+        accession_number: Union[str, None], optional
            Accession number of the study
-        study_date: Union[str, datetime.date], optional
+        study_date: Union[str, datetime.date, None], optional
            Date of study creation
-        study_time: Union[str, datetime.time], optional
+        study_time: Union[str, datetime.time, None], optional
            Time of study creation
-        referring_physician_name: str, optional
+        referring_physician_name: Union[str, pydicom.valuerep.PersonName, None], optional
             Name of the referring physician
-        pixel_spacing: Tuple[int, int], optional
+        pixel_spacing: Union[Tuple[int, int], None], optional
             Physical spacing in millimeter between pixels along the row and
             column dimension
-        laterality: Union[str, highdicom.enum.LateralityValues], optional
+        laterality: Union[str, highdicom.LateralityValues, None], optional
             Laterality of the examined body part
         patient_orientation:
-                Union[Tuple[str, str], Tuple[highdicom.enum.PatientOrientationValuesBiped, highdicom.enum.PatientOrientationValuesBiped], Tuple[highdicom.enum.PatientOrientationValuesQuadruped, highdicom.enum.PatientOrientationValuesQuadruped]], optional
+                Union[Tuple[str, str], Tuple[highdicom.PatientOrientationValuesBiped, highdicom.PatientOrientationValuesBiped], Tuple[highdicom.PatientOrientationValuesQuadruped, highdicom.PatientOrientationValuesQuadruped], None], optional
             Orientation of the patient along the row and column axes of the
             image (required if `coordinate_system` is ``"PATIENT"``)
-        anatomical_orientation_type: Union[str, highdicom.enum.AnatomicalOrientationTypeValues], optional
+        anatomical_orientation_type: Union[str, highdicom.AnatomicalOrientationTypeValues, None], optional
             Type of anatomical orientation of patient relative to image (may be
             provide if `coordinate_system` is ``"PATIENT"`` and patient is
             an animal)
-        container_identifier: str, optional
+        container_identifier: Union[str, None], optional
             Identifier of the container holding the specimen (required if
             `coordinate_system` is ``"SLIDE"``)
-        issuer_of_container_identifier: highdicom.IssuerOfIdentifier, optional
+        issuer_of_container_identifier: Union[highdicom.IssuerOfIdentifier, None], optional
             Issuer of `container_identifier`
-        specimen_descriptions: Sequence[highdicom.SpecimenDescriptions], optional
+        specimen_descriptions: Union[Sequence[highdicom.SpecimenDescriptions], None], optional
             Description of each examined specimen (required if
             `coordinate_system` is ``"SLIDE"``)
         transfer_syntax_uid: str, optional
@@ -171,7 +174,7 @@ class SCImage(SOPClass):
             Additional keyword arguments that will be passed to the constructor
             of `highdicom.base.SOPClass`
 
-        """  # noqa
+        """  # noqa: E501
         supported_transfer_syntaxes = {
             ImplicitVRLittleEndian,
             ExplicitVRLittleEndian,
@@ -182,6 +185,12 @@ class SCImage(SOPClass):
                 f'Transfer syntax "{transfer_syntax_uid}" is not supported'
             )
 
+        # Check names
+        if patient_name is not None:
+            check_person_name(patient_name)
+        if referring_physician_name is not None:
+            check_person_name(referring_physician_name)
+
         super().__init__(
             study_instance_uid=study_instance_uid,
             series_instance_uid=series_instance_uid,
@@ -261,7 +270,8 @@ class SCImage(SOPClass):
                 self.IssuerOftheContainerIdentifierSequence.append(
                     issuer_of_container_identifier
                 )
-            container_type_item = CodedConcept(*codes.SCT.MicroscopeSlide)
+            code: Code = codes.SCT.MicroscopeSlide
+            container_type_item = CodedConcept(*code)
             self.ContainerTypeCodeSequence = [container_type_item]
             self.SpecimenDescriptionSequence = specimen_descriptions
 
@@ -360,3 +370,158 @@ class SCImage(SOPClass):
             self.PixelData = encapsulate([encoded_frame])
         else:
             self.PixelData = encoded_frame
+
+    @classmethod
+    def from_ref_dataset(
+        cls,
+        ref_dataset: Dataset,
+        pixel_array: np.ndarray,
+        photometric_interpretation: Union[
+            str,
+            PhotometricInterpretationValues
+        ],
+        bits_allocated: int,
+        coordinate_system: Union[str, CoordinateSystemNames],
+        series_instance_uid: str,
+        series_number: int,
+        sop_instance_uid: str,
+        instance_number: int,
+        manufacturer: str,
+        pixel_spacing: Optional[Tuple[int, int]] = None,
+        laterality: Optional[Union[str, LateralityValues]] = None,
+        patient_orientation: Optional[
+            Union[
+                Tuple[str, str],
+                Tuple[
+                    PatientOrientationValuesBiped,
+                    PatientOrientationValuesBiped,
+                ],
+                Tuple[
+                    PatientOrientationValuesQuadruped,
+                    PatientOrientationValuesQuadruped,
+                ]
+            ]
+        ] = None,
+        anatomical_orientation_type: Optional[
+            Union[str, AnatomicalOrientationTypeValues]
+        ] = None,
+        container_identifier: Optional[str] = None,
+        issuer_of_container_identifier: Optional[IssuerOfIdentifier] = None,
+        specimen_descriptions: Optional[
+            Sequence[SpecimenDescription]
+        ] = None,
+        transfer_syntax_uid: str = ImplicitVRLittleEndian,
+        **kwargs: Any
+    ) -> 'SCImage':
+        """Constructor that copies patient and study from an existing dataset.
+
+        This provides a more concise way to construct an SCImage when an
+        existing reference dataset from the study is available. All patient-
+        and study- related attributes required by the main constructor are
+        copied from the ``ref_dataset``, if present.
+
+        The ``ref_dataset`` may be any dataset
+        from the study to which the resulting SC image should belong, and
+        contain all the relevant patient and study metadata. It does not need to
+        be specifically related to the contents of the SCImage.
+
+        Parameters
+        ----------
+        ref_dataset: pydicom.dataset.Dataset
+            An existing dataset from the study to which the SCImage should
+            belong. Patient- and study-related metadata will be copied from
+            this dataset.
+        pixel_array: numpy.ndarray
+            Array of unsigned integer pixel values representing a single-frame
+            image; either a 2D grayscale image or a 3D color image
+            (RGB color space)
+        photometric_interpretation: Union[str, highdicom.enum.PhotometricInterpretationValues]
+            Interpretation of pixel data; either ``"MONOCHROME1"`` or
+            ``"MONOCHROME2"`` for 2D grayscale images or ``"RGB"`` or
+            ``"YBR_FULL"`` for 3D color images
+        bits_allocated: int
+            Number of bits that should be allocated per pixel value
+        coordinate_system: Union[str, highdicom.enum.CoordinateSystemNames]
+            Subject (``"PATIENT"`` or ``"SLIDE"``) that was the target of
+            imaging
+        series_instance_uid: str
+            Series Instance UID of the SC image series
+        series_number: Union[int, None]
+            Series Number of the SC image series
+        sop_instance_uid: str
+            SOP instance UID that should be assigned to the SC image instance
+        instance_number: int
+            Number that should be assigned to this SC image instance
+        manufacturer: str
+            Name of the manufacturer of the device that creates the SC image
+            instance (in a research setting this is typically the same
+            as `institution_name`)
+        pixel_spacing: Union[Tuple[int, int]], optional
+            Physical spacing in millimeter between pixels along the row and
+            column dimension
+        laterality: Union[str, highdicom.enum.LateralityValues, None], optional
+            Laterality of the examined body part
+        patient_orientation:
+                Union[Tuple[str, str], Tuple[highdicom.enum.PatientOrientationValuesBiped, highdicom.enum.PatientOrientationValuesBiped], Tuple[highdicom.enum.PatientOrientationValuesQuadruped, highdicom.enum.PatientOrientationValuesQuadruped], None], optional
+            Orientation of the patient along the row and column axes of the
+            image (required if `coordinate_system` is ``"PATIENT"``)
+        anatomical_orientation_type: Union[str, highdicom.enum.AnatomicalOrientationTypeValues, None], optional
+            Type of anatomical orientation of patient relative to image (may be
+            provide if `coordinate_system` is ``"PATIENT"`` and patient is
+            an animal)
+        container_identifier: Union[str], optional
+            Identifier of the container holding the specimen (required if
+            `coordinate_system` is ``"SLIDE"``)
+        issuer_of_container_identifier: Union[highdicom.IssuerOfIdentifier, None], optional
+            Issuer of `container_identifier`
+        specimen_descriptions: Union[Sequence[highdicom.SpecimenDescriptions], None], optional
+            Description of each examined specimen (required if
+            `coordinate_system` is ``"SLIDE"``)
+        transfer_syntax_uid: str, optional
+            UID of transfer syntax that should be used for encoding of
+            data elements. The following lossless compressed transfer syntaxes
+            are supported: RLE Lossless (``"1.2.840.10008.1.2.5"``).
+        **kwargs: Any, optional
+            Additional keyword arguments that will be passed to the constructor
+            of `highdicom.base.SOPClass`
+
+        Returns
+        -------
+        SCImage
+            Secondary capture image.
+
+        """  # noqa: E501
+        return cls(
+            pixel_array=pixel_array,
+            photometric_interpretation=photometric_interpretation,
+            bits_allocated=bits_allocated,
+            coordinate_system=coordinate_system,
+            study_instance_uid=ref_dataset.StudyInstanceUID,
+            series_instance_uid=series_instance_uid,
+            series_number=series_number,
+            sop_instance_uid=sop_instance_uid,
+            instance_number=instance_number,
+            manufacturer=manufacturer,
+            patient_id=getattr(ref_dataset, 'PatientID', None),
+            patient_name=getattr(ref_dataset, 'PatientName', None),
+            patient_birth_date=getattr(ref_dataset, 'PatientBirthDate', None),
+            patient_sex=getattr(ref_dataset, 'PatientSex', None),
+            accession_number=getattr(ref_dataset, 'AccessionNumber', None),
+            study_id=getattr(ref_dataset, 'StudyID', None),
+            study_date=getattr(ref_dataset, 'StudyDate', None),
+            study_time=getattr(ref_dataset, 'StudyTime', None),
+            referring_physician_name=getattr(
+                ref_dataset,
+                'ReferringPhysicianName',
+                None
+            ),
+            pixel_spacing=pixel_spacing,
+            laterality=laterality,
+            patient_orientation=patient_orientation,
+            anatomical_orientation_type=anatomical_orientation_type,
+            container_identifier=container_identifier,
+            issuer_of_container_identifier=issuer_of_container_identifier,
+            specimen_descriptions=specimen_descriptions,
+            transfer_syntax_uid=transfer_syntax_uid,
+            **kwargs
+        )
